=== modified file 'Makefile'
--- Makefile	2006-06-29 09:15:47 +0000
+++ Makefile	2006-07-25 14:39:41 +0000
@@ -64,8 +64,8 @@
 
 # win32 python's distutils-based installer
 # require to have python interpreter installed on win32
-python-installer:
-	python setup.py bdist_wininst --target-version=2.4 --title="Bazaar-NG" --install-script="bzr-win32-bdist-postinstall.py"
+python-installer: docs
+	python setup.py bdist_wininst --title="Bazaar-NG" --install-script="bzr-win32-bdist-postinstall.py"
 
 
 # clean on win32 all installer-related files and directories

=== modified file 'setup.py'
--- setup.py	2006-07-25 14:11:48 +0000
+++ setup.py	2006-07-25 14:39:41 +0000
@@ -130,10 +130,15 @@
 ########################
 
 if 'bdist_wininst' in sys.argv:
+    import glob
+    # doc files
+    docs = glob.glob('doc/*.htm') + ['doc/default.css']
     # python's distutils-based win32 installer
     ARGS = {'scripts': ['bzr', 'tools/win32/bzr-win32-bdist-postinstall.py'],
             # install the txt files from bzrlib.doc.api.
             'package_data': {'bzrlib': ['doc/api/*.txt']},
+            # help pages
+            'data_files': [('Doc/Bazaar-NG', docs)],
            }
 
     ARGS.update(META_INFO)

=== modified file 'tools/win32/bzr-win32-bdist-postinstall.py'
--- tools/win32/bzr-win32-bdist-postinstall.py	2006-06-29 09:15:47 +0000
+++ tools/win32/bzr-win32-bdist-postinstall.py	2006-07-16 06:58:25 +0000
@@ -18,6 +18,8 @@
 
 import os
 import sys
+import _winreg
+
 
 if len(sys.argv) == 2 and sys.argv[1] == "-install":
     # try to detect version number automatically
@@ -57,3 +59,55 @@
         print "Use this batch file to run bzr"
     except Exception, e:
         print "ERROR: Unable to create %s: %s" % (batch_path, e)
+
+    # make entry in APPDATA
+    appdata = get_special_folder_path("CSIDL_APPDATA")
+    dst = os.path.join(appdata, "bazaar", "2.0")
+    if not os.path.isdir(dst):
+        os.makedirs(dst)
+        import locale
+        print "Configuration files stored in %s" % \
+              dst.encode(locale.getpreferredencoding(), 'replace')
+        # create dummy bazaar.conf
+        f = file(os.path.join(dst,'bazaar.conf'), 'w')
+        f.write("# main configuration file of Bazaar-NG\n"
+                "[DEFAULT]\n"
+                "#email=Your Name <you@domain.com>\n")
+        f.close()
+
+    ## this hunk borrowed from pywin32_postinstall.py
+    # use bdist_wininst builtins to create a shortcut.
+    # CSIDL_COMMON_PROGRAMS only available works on NT/2000/XP, and
+    # will fail there if the user has no admin rights.
+    if get_root_hkey()==_winreg.HKEY_LOCAL_MACHINE:
+        try:
+            fldr = get_special_folder_path("CSIDL_COMMON_PROGRAMS")
+        except OSError:
+            # No CSIDL_COMMON_PROGRAMS on this platform
+            fldr = get_special_folder_path("CSIDL_PROGRAMS")
+    else:
+        # non-admin install - always goes in this user's start menu.
+        fldr = get_special_folder_path("CSIDL_PROGRAMS")
+
+    # make Bazaar-NG entry
+    fldr = os.path.join(fldr, 'Bazaar-NG')
+    if not os.path.isdir(fldr):
+        os.mkdir(fldr)
+        directory_created(fldr)
+
+    # link to documentation
+    docs = os.path.join(sys.exec_prefix, 'Doc', 'Bazaar-NG', 'index.htm')
+    dst = os.path.join(fldr, 'Documentation.lnk')
+    create_shortcut(docs, 'Bazaar-NG Documentation', dst)
+    file_created(dst)
+    print 'Documentation for Bazaar-NG: Start => Programs => Bazaar-NG'
+
+    # bzr in cmd shell
+    cmd = os.environ.get('COMSPEC', 'cmd.exe')
+    dst = os.path.join(fldr, 'Start bzr.lnk')
+    create_shortcut(cmd,
+                    'Start bzr in cmd shell',
+                    dst,
+                    "/K bzr help",
+                    os.path.join(sys.exec_prefix, 'Scripts'))
+    file_created(dst)

